# IDE integration

FlakeHell provides `flake8helled` binary that runs `lint` command to make it possible to use FlakeHell instead of Flake8 in any IDE.

1. Open Flake8 plugin settings in your IDE.
1. Find something like "Executable Path"
1. Put `flake8helled` in this field.
